﻿##############################################################################
##
## Power Shell Module for Proxy Gateway Server Object Model Constants
##
##############################################################################

#
# Gateway Group Types
#
Set-Variable groupTypeNormal -Option Constant -Value 0x00000000
Set-Variable groupTypeSystem -Option Constant -Value 0x40000000
Set-Variable groupTypeAllHosts -Option Constant -Value ($script:groupTypeSystem -bor 0x1)
Set-Variable groupTypeSystemInfo -Option Constant -Value ($script:groupTypeSystem -bor 0x2)
Set-Variable groupTypeDebugging -Option Constant -Value ($script:groupTypeSystem -bor 0x4)
Set-Variable groupTypeTransientHosts -Option Constant -Value ($script:groupTypeSystem -bor 0x8)

#
# Win32_ACE Class constants
#
Set-Variable _ACE_Flag_OBJECT_INHERIT_ACE -Option Constant -Value 0x1
Set-Variable _ACE_Flag_CONTAINER_INHERIT_ACE -Option Constant -Value 0x2

Set-Variable _ACE_Type_Access_Allowed -Option Constant -Value 0x0
Set-Variable _ACE_Type_Access_Denied -Option Constant -Value 0x1
Set-Variable _ACE_Type_Audit -Option Constant -Value 0x2

#
# Access Rights Constants
#
# Standart rights
Set-Variable DELETE -Option Constant -Value 0x00010000
Set-Variable READ_CONTROL -Option Constant -Value 0x00020000
Set-Variable WRITE_DAC -Option Constant -Value 0x00040000
Set-Variable WRITE_OWNER -Option Constant -Value 0x00080000

# Gateway security rights
Set-Variable gatewayConnect -Option Constant -Value 0x0001
Set-Variable gatewayReadClientConnections -Option Constant -Value 0x0002
Set-Variable gatewayModifyClientConnections -Option Constant -Value 0x0004
Set-Variable gatewayReadActiveRecordings -Option Constant -Value 0x0008
Set-Variable gatewayModifyActiveRecordings -Option Constant -Value 0x0010
Set-Variable gatewayReadActiveMasters -Option Constant -Value 0x0020
Set-Variable gatewayModifyActiveMasters -Option Constant -Value 0x0040
Set-Variable gatewaySendIPCData -Option Constant -Value 0x0080
Set-Variable gatewayReadActiveHosts -Option Constant -Value 0x0100
Set-Variable gatewayModifyActiveHosts -Option Constant -Value 0x0200
Set-Variable gatewayManageHosts -Option Constant -Value 0x0400
Set-Variable gatewayCreateGroups -Option Constant -Value 0x0800
# note: for v5.0 we exclude recording and sendIPC  Also, can't DELETE the Gateway
Set-Variable v50_gatewayAllRights -Option Constant -Value (0x0f67 -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)
# note: for v5.10 we include recording and sendIPC
Set-Variable gatewayAllRights -Option Constant -Value (0x0fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)

# Common Gateway security rights sets
Set-Variable gatewayConnectFromMaster -Option Constant -Value $script:gatewayConnect
Set-Variable gatewayViewInformation -Option Constant -Value ($script:gatewayConnect -bor $script:gatewayReadActiveMasters -bor $script:gatewayReadActiveHosts -bor $script:gatewayReadActiveRecordings -bor $script:gatewayReadClientConnections)
Set-Variable gatewayModifyInformation -Option Constant -Value ($script:gatewayViewInformation -bor $script:gatewayModifyActiveHosts -bor $script:gatewaySendIPCData -bor $script:gatewayModifyActiveMasters -bor $script:gatewayModifyActiveRecordings -bor $script:gatewayModifyClientConnections)
Set-Variable gatewayEditSecurity -Option Constant -Value ($script:gatewayConnect -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)

# Group security rights
Set-Variable groupRead -Option Constant -Value 0x0001
Set-Variable groupModify -Option Constant -Value 0x0002
Set-Variable groupAllRights -Option Constant -Value (0x0003 -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE)

# Common Group security rights sets
Set-Variable groupVisible -Option Constant -Value $script:groupRead
Set-Variable groupModifyGroup -Option Constant -Value ($script:groupRead -bor $script:groupModify)
Set-Variable groupDeleteGroup -Option Constant -Value ($script:groupRead -bor $script:DELETE)
Set-Variable groupEditSecurity -Option Constant -Value ($script:groupRead -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)

# Host security rights
Set-Variable hostRead -Option Constant -Value 0x0001
Set-Variable hostConnect -Option Constant -Value 0x0002
Set-Variable hostRemoteView -Option Constant -Value 0x0004
Set-Variable hostRemoteControl -Option Constant -Value 0x0008
Set-Variable hostFileTransferRead -Option Constant -Value 0x0010
Set-Variable hostFileTransferWrite -Option Constant -Value 0x0020
Set-Variable hostRemotePrinting -Option Constant -Value 0x0040
Set-Variable hostClipboardRead -Option Constant -Value 0x0080
Set-Variable hostClipboardWrite -Option Constant -Value 0x0100
Set-Variable hostStartRecording -Option Constant -Value 0x0200
Set-Variable hostTakeInputControl -Option Constant -Value 0x0400
Set-Variable hostAdmin -Option Constant -Value 0x0800
Set-Variable hostChat -Option Constant -Value 0x1000
Set-Variable hostRemoteManagement -Option Constant -Value 0x2000
# note: special right given only to SuperAdmins who aren't subject to 
Set-Variable hostBypassConnectionPermission -Option Constant -Value 0x8000	
# note: for v5.0 we exclude hostStartRecording
Set-Variable v50_hostAllRights -Option Constant -Value (0x0dff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE)
# note: for v5.10 we include hostStartRecording
Set-Variable v510_hostAllRights -Option Constant -Value (0x0fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE)
# note: for v6.0 we include hostChat
Set-Variable v60_hostAllRights -Option Constant -Value (0x1fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE)
# note: for v6.10 we include hostRemoteManagement
Set-Variable hostAllRights -Option Constant -Value (0x3fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE)

# Common Host security rights sets
Set-Variable hostViewOnly -Option Constant -Value ($script:hostStartRecording -bor $script:hostRemoteView -bor $script:hostConnect -bor $script:hostRead)
Set-Variable hostRemoteControlCmn -Option Constant -Value ($script:hostViewOnly -bor $script:hostTakeInputControl -bor $script:hostRemoteControl)
Set-Variable hostFileTransfer -Option Constant -Value ($script:hostFileTransferWrite -bor $script:hostFileTransferRead -bor $script:hostConnect -bor $script:hostRead)
Set-Variable hostRemoteAdministration -Option Constant -Value ($script:hostAdmin -bor $script:hostRead)
Set-Variable hostEditSecurity -Option Constant -Value ($script:hostRead -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)
Set-Variable hostFullUser -Option Constant -Value ($script:hostRemoteControlCmn -bor $script:hostEditSecurity -bor $script:hostFileTransfer -bor $script:hostRemoteManagement -bor $script:hostChat`
                                       -bor $script:hostRemotePrinting  -bor $script:hostClipboardWrite -bor $script:hostClipboardRead -bor $script:hostAdmin)

# Operation security rights
Set-Variable operationRecordToFile -Option Constant -Value 0x0001
Set-Variable operationConnectToFile -Option Constant -Value 0x0002
Set-Variable operationImportSession -Option Constant -Value 0x0004
# note: no need for operationRemoveSession -- that's covered by DELETE on the session record
Set-Variable operationDiagnosticAccess -Option Constant -Value 0x0008
# note: can't DELETE the Operations
Set-Variable operationAllRights -Option Constant -Value (0x000F -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)

# Common Operation security rights sets
Set-Variable operationViewDiagnostics -Option Constant -Value $script:operationDiagnosticAccess
Set-Variable operationEditSecurity -Option Constant -Value ($script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)


# Session security rights
Set-Variable sessionRead -Option Constant -Value 0x0001
Set-Variable sessionPlay -Option Constant -Value 0x0002
# new for v5.10, but so far only used internally 
Set-Variable sessionModify -Option Constant -Value 0x0004 
# note: for v5.10 we exclude sessionModify, since it isn't needed for any external operation
Set-Variable sessionAllRights -Option Constant -Value (0x0003 -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE)

# Common Session security rights sets
Set-Variable sessionPlayRecordedSession -Option Constant -Value ($script:sessionRead -bor $script:sessionPlay)
Set-Variable sessionDeleteSession -Option Constant -Value ($script:sessionRead -bor $script:DELETE)
Set-Variable sessionEditSecurity -Option Constant -Value ($script:sessionRead -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)

# Settings security rights
Set-Variable settingsRead -Option Constant -Value 0x0001
Set-Variable settingsWrite -Option Constant -Value 0x0002
Set-Variable settingsReadLicenses -Option Constant -Value 0x0004
Set-Variable settingsWriteLicenses -Option Constant -Value 0x0008
Set-Variable settingsReadPollSettings -Option Constant -Value 0x0010
Set-Variable settingsWritePollSettings -Option Constant -Value 0x0020
Set-Variable settingsReadProtocols -Option Constant -Value 0x0040
Set-Variable settingsWriteProtocols -Option Constant -Value 0x0080
Set-Variable settingsReadAuditSettings -Option Constant -Value 0x0100
Set-Variable settingsWriteAuditSettings -Option Constant -Value 0x0200
Set-Variable settingsReadEncryption -Option Constant -Value 0x0400
Set-Variable settingsWriteEncryption -Option Constant -Value 0x0800
Set-Variable settingsReadRecordingSettings -Option Constant -Value 0x1000
Set-Variable settingsWriteRecordingSettings -Option Constant -Value 0x2000
# note: can't DELETE the Settings
Set-Variable v50_settingsAllRights -Option Constant -Value (0x0fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)
Set-Variable settingsAllRights -Option Constant -Value (0x3fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)

# Common Settings security rights sets
Set-Variable settingsViewSettings -Option Constant -Value ($script:settingsReadEncryption -bor $script:settingsReadAuditSettings -bor $script:settingsReadProtocols -bor $script:settingsReadPollSettings`
                                -bor $script:settingsReadRecordingSettings -bor $script:settingsReadLicenses -bor $script:settingsRead)
Set-Variable settingsModifySettings -Option Constant -Value ($script:settingsViewSettings  -bor $script:settingsWriteAuditSettings -bor $script:settingsWriteProtocols -bor $script:settingsWritePollSettings`
                                -bor $script:settingsWriteEncryption -bor $script:settingsWriteRecordingSettings -bor $script:settingsWriteLicenses -bor $script:settingsWrite)
Set-Variable settingsEditSecurity -Option Constant -Value ($script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)

#
# Security rights Name Maps = @{ accessRightBinaryFlag = "accessRightName" }
#
Set-Variable settingsSecRightsMap -Option Constant -Value @{ 
    0x00010000 = "DELETE";
    0x00020000 = "READ_CONTROL";
    0x00040000 = "WRITE_DAC";
    0x00080000 = "WRITE_OWNER";
    0x0001 = "settingsRead";
    0x0002 = "settingsWrite";
    0x0004 = "settingsReadLicenses";
    0x0008 = "settingsWriteLicenses";
    0x0010 = "settingsReadPollSettings";
    0x0020 = "settingsWritePollSettings";
    0x0040 = "settingsReadProtocols";
    0x0080 = "settingsWriteProtocols";
    0x0100 = "settingsReadAuditSettings";
    0x0200 = "settingsWriteAuditSettings";
    0x0400 = "settingsReadEncryption";
    0x0800 = "settingsWriteEncryption";
    0x1000 = "settingsReadRecordingSettings";
    0x2000 = "settingsWriteRecordingSettings";
    (0x0fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER) = "v50_settingsAllRights";
    (0x3fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER) = "settingsAllRights"}

Set-Variable gatewaySecRightsMap -Option Constant -Value @{ 
    0x00010000 = "DELETE";
    0x00020000 = "READ_CONTROL";
    0x00040000 = "WRITE_DAC";
    0x00080000 = "WRITE_OWNER";
    0x0001 = "gatewayConnect";
    0x0002 = "gatewayReadClientConnections";
    0x0004 = "gatewayModifyClientConnections";
    0x0008 = "gatewayReadActiveRecordings";
    0x0010 = "gatewayModifyActiveRecordings";
    0x0020 = "gatewayReadActiveMasters";
    0x0040 = "gatewayModifyActiveMasters";
    0x0080 = "gatewaySendIPCData";
    0x0100 = "gatewayReadActiveHosts";
    0x0200 = "gatewayModifyActiveHosts";
    0x0400 = "gatewayManageHosts";
    0x0800 = "gatewayCreateGroups";
    (0x0f67 -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER) = "v50_gatewayAllRights";
    (0x0fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER) = "gatewayAllRights"}

Set-Variable groupSecRightsMap -Option Constant -Value @{ 
    0x00010000 = "DELETE";
    0x00020000 = "READ_CONTROL";
    0x00040000 = "WRITE_DAC";
    0x00080000 = "WRITE_OWNER";
    0x0001 = "groupRead";
    0x0002 = "groupModify";
    (0x0003 -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE) = "groupAllRights"}

Set-Variable hostSecRightsMap -Option Constant -Value @{ 
    0x00010000 = "DELETE";
    0x00020000 = "READ_CONTROL";
    0x00040000 = "WRITE_DAC";
    0x00080000 = "WRITE_OWNER";
    0x0001 = "hostRead";
    0x0002 = "hostConnect";
    0x0004 = "hostRemoteView";
    0x0008 = "hostRemoteControl";
    0x0010 = "hostFileTransferRead";
    0x0020 = "hostFileTransferWrite";
    0x0040 = "hostRemotePrinting";
    0x0080 = "hostClipboardRead";
    0x0100 = "hostClipboardWrite";
    0x0200 = "hostStartRecording";
    0x0400 = "hostTakeInputControl";
    0x0800 = "hostAdmin";
    0x1000 = "hostChat";
    0x2000 = "hostRemoteManagement";
    0x8000 = "hostBypassConnectionPermission";
    (0x0dff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE) = "v50_hostAllRights";
    (0x0fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE) = "v510_hostAllRights";
    (0x1fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE) = "v60_hostAllRights";
    (0x3fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE) = "hostAllRights"}

Set-Variable operationSecRightsMap -Option Constant -Value @{ 
    0x00010000 = "DELETE";
    0x00020000 = "READ_CONTROL";
    0x00040000 = "WRITE_DAC";
    0x00080000 = "WRITE_OWNER";
    0x0001 = "operationRecordToFile";
    0x0002 = "operationConnectToFile";
    0x0004 = "operationImportSession";
    0x0008 = "operationDiagnosticAccess";
    (0x000F -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER) = "operationAllRights"}

Set-Variable sessionSecRightsMap -Option Constant -Value @{ 
    0x00010000 = "DELETE";
    0x00020000 = "READ_CONTROL";
    0x00040000 = "WRITE_DAC";
    0x00080000 = "WRITE_OWNER";
    0x0001 = "sessionRead";
    0x0002 = "sessionPlay";
    0x0004 = "sessionModify";
    (0x0003 -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE) = "sessionAllRights"}

#
# Host security rights enums
#

# HostAdminRights Enum
Set-Variable hostadminConnectLocally -Option Constant -Value 0x01
Set-Variable hostadminReadHostStatus -Option Constant -Value 0x02
Set-Variable hostadminTerminateConnection -Option Constant -Value 0x04
Set-Variable hostadminConnectRemotely -Option Constant -Value 0x08
Set-Variable hostadminAllRights -Option Constant -Value 0x0F
 
Set-Variable hostAdminSecRightsMap -Option Constant -Value @{ 
	0x01 = "hostadminConnectLocally";
	0x02 = "hostadminReadHostStatus";
	0x04 = "hostadminTerminateConnection";
	0x08 = "hostadminConnectRemotely";
	0x0F = "hostadminAllRights"
}

# HostServiceRights Enum
Set-Variable hostserviceConnect -Option Constant -Value 0x01
Set-Variable hostserviceRemoteView -Option Constant -Value 0x02
Set-Variable hostserviceRemoteControl -Option Constant -Value 0x04
Set-Variable hostserviceFileTransferRead -Option Constant -Value 0x08
Set-Variable hostserviceFileTransferWrite -Option Constant -Value 0x10
Set-Variable hostserviceRemotePrinting -Option Constant -Value 0x20
Set-Variable hostserviceClipboardTransferRead -Option Constant -Value 0x40
Set-Variable hostserviceClipboardTransferWrite -Option Constant -Value 0x80
Set-Variable hostserviceAllRights -Option Constant -Value 0xFF
 
Set-Variable hostServiceSecRightsMap -Option Constant -Value @{ 
	0x01 = "hostserviceConnect";
	0x02 = "hostserviceRemoteView";
	0x04 = "hostserviceRemoteControl";
	0x08 = "hostserviceFileTransferRead";
	0x10 = "hostserviceFileTransferWrite";
	0x20 = "hostserviceRemotePrinting";
	0x40 = "hostserviceClipboardTransferRead";
	0x80 = "hostserviceClipboardTransferWrite";
	0xFF = "hostserviceAllRights"
}

# HostSettingsRights Enum
Set-Variable hostsettingsRead -Option Constant -Value 0x01
Set-Variable hostsettingsWrite -Option Constant -Value 0x02
Set-Variable hostsettingsWriteAccess -Option Constant -Value 0x04
Set-Variable hostsettingsReadLicenses -Option Constant -Value 0x08
Set-Variable hostsettingsWriteLicenses -Option Constant -Value 0x10
Set-Variable hostsettingsReadGatewayConfigs -Option Constant -Value 0x20
Set-Variable hostsettingsWriteGatewayConfigs -Option Constant -Value 0x40
Set-Variable hostsettingsReadConfiguration -Option Constant -Value 0x80
Set-Variable hostsettingsWriteEx -Option Constant -Value 0x100
Set-Variable hostsettingsReadWriteExtensionTags -Option Constant -Value 0x200
Set-Variable hostsettingsAllRights -Option Constant -Value 0x2FF

Set-Variable hostSettingsSecRightsMap -Option Constant -Value @{ 
	0x01 = "hostsettingsRead";
	0x02 = "hostsettingsWrite";
	0x04 = "hostsettingsWriteAccess";
	0x08 = "hostsettingsReadLicenses";
	0x10 = "hostsettingsWriteLicenses";
	0x20 = "hostsettingsReadGatewayConfigs";
	0x40 = "hostsettingsWriteGatewayConfigs";
	0x80 = "hostsettingsReadConfiguration";
	0x100 = "hostsettingsWriteEx";
	0x200 = "hostsettingsReadWriteExtensionTags";
	0x2FF = "hostsettingsAllRights"
}


#
# Host settings enums
#

# WindowAppearance Enum
Set-Variable windowHide -Option Constant -Value 0
Set-Variable windowIcon -Option Constant -Value 2

Set-Variable windowAppearance -Option Constant -Value @{ 
    0 = "windowHide";
    2 = "windowIcon"}

# hostNotifications Property
Set-Variable notifyOnConnectDisconnect -Option Constant -Value 0x01
Set-Variable notifyOnFileTransferOperations -Option Constant -Value 0x02
Set-Variable notifyShowActiveUsersAtConnect -Option Constant -Value 0x10000

Set-Variable hostNotificationsMap -Option Constant -Value @{ 
    0x01    = "notifyOnConnectDisconnect";
    0x02    = "notifyOnFileTransferOperations";
    0x10000 = "notifyShowActiveUsersAtConnect"}

# SuppressKeys Enum
Set-Variable suppressAlways -Option Constant -Value 0
Set-Variable suppressPermit -Option Constant -Value 1
Set-Variable suppressNever -Option Constant -Value 2

Set-Variable suppressKeysMap -Option Constant -Value @{ 
    0 = "suppressAlways";
    1 = "suppressPermit";
    2 = "suppressNever"}

# HostAccess Enum
Set-Variable accessPermit -Option Constant -Value 0
Set-Variable accessLocked -Option Constant -Value 1
Set-Variable accessTime -Option Constant -Value 2

Set-Variable hostAccessMap -Option Constant -Value @{ 
    0 = "accessPermit";
    1 = "accessLocked";
    2 = "accessTime"}

# HostPermission Enum
Set-Variable permitNone -Option Constant -Value 0
Set-Variable permitGrant -Option Constant -Value 1
Set-Variable permitRequest -Option Constant -Value 2

Set-Variable hostPermissionMap -Option Constant -Value @{ 
    0 = "permitNone";
    1 = "permitGrant";
    2 = "permitRequest"}

# ManageVisualEffectsMode Enum
Set-Variable manageAlways -Option Constant -Value 0
Set-Variable managePermit -Option Constant -Value 1
Set-Variable manageNever -Option Constant -Value 2

Set-Variable manageVisualEffectsModeMap -Option Constant -Value @{ 
    0 = "manageAlways";
    1 = "managePermit";
    2 = "manageNever"}

# VisualEffectsFlags Enum
Set-Variable veNone -Option Constant -Value 0x00
Set-Variable veActiveDesktop -Option Constant -Value 0x01
Set-Variable veWallPaper -Option Constant -Value 0x02
Set-Variable veMouseEffects -Option Constant -Value 0x04
Set-Variable veFontSmoothing -Option Constant -Value 0x08
Set-Variable veWindowEffects -Option Constant -Value 0x10
Set-Variable veFullDrag -Option Constant -Value 0x20
Set-Variable veScreenSaver -Option Constant -Value 0x40
Set-Variable veAllEffects -Option Constant -Value 0x7F

Set-Variable visualEffectsFlagsMap -Option Constant -Value @{ 
    0x00 = "veNone";
    0x01 = "veActiveDesktop";
    0x02 = "veWallPaper";
    0x04 = "veMouseEffects";
    0x08 = "veFontSmoothing";
    0x10 = "veWindowEffects";
    0x20 = "veFullDrag";
    0x40 = "veScreenSaver";
    0x7F = "veAllEffects"}


#
# Module exports
#
Export-ModuleMember -Variable *

# SIG # Begin signature block
# MIIXcgYJKoZIhvcNAQcCoIIXYzCCF18CAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUSGwzTHntSk9eybNO/JsX+70E
# qiKgghLuMIIDnzCCAoegAwIBAgIQeaKlhfnRFUIT2bg+9raN7TANBgkqhkiG9w0B
# AQUFADBTMQswCQYDVQQGEwJVUzEXMBUGA1UEChMOVmVyaVNpZ24sIEluYy4xKzAp
# BgNVBAMTIlZlcmlTaWduIFRpbWUgU3RhbXBpbmcgU2VydmljZXMgQ0EwHhcNMTIw
# NTAxMDAwMDAwWhcNMTIxMjMxMjM1OTU5WjBiMQswCQYDVQQGEwJVUzEdMBsGA1UE
# ChMUU3ltYW50ZWMgQ29ycG9yYXRpb24xNDAyBgNVBAMTK1N5bWFudGVjIFRpbWUg
# U3RhbXBpbmcgU2VydmljZXMgU2lnbmVyIC0gRzMwgZ8wDQYJKoZIhvcNAQEBBQAD
# gY0AMIGJAoGBAKlZZnTaPYp9etj89YBEe/5HahRVTlBHC+zT7c72OPdPabmx8LZ4
# ggqMdhZn4gKttw2livYD/GbT/AgtzLVzWXuJ3DNuZlpeUje0YtGSWTUUi0WsWbJN
# JKKYlGhCcp86aOJri54iLfSYTprGr7PkoKs8KL8j4ddypPIQU2eud69RAgMBAAGj
# geMwgeAwDAYDVR0TAQH/BAIwADAzBgNVHR8ELDAqMCigJqAkhiJodHRwOi8vY3Js
# LnZlcmlzaWduLmNvbS90c3MtY2EuY3JsMBYGA1UdJQEB/wQMMAoGCCsGAQUFBwMI
# MDQGCCsGAQUFBwEBBCgwJjAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AudmVyaXNp
# Z24uY29tMA4GA1UdDwEB/wQEAwIHgDAeBgNVHREEFzAVpBMwETEPMA0GA1UEAxMG
# VFNBMS0zMB0GA1UdDgQWBBS0t/GJSSZg52Xqc67c0zjNv1eSbzANBgkqhkiG9w0B
# AQUFAAOCAQEAHpiqJ7d4tQi1yXJtt9/ADpimNcSIydL2bfFLGvvV+S2ZAJ7R55uL
# 4T+9OYAMZs0HvFyYVKaUuhDRTour9W9lzGcJooB8UugOA9ZresYFGOzIrEJ8Byyn
# PQhm3ADt/ZQdc/JymJOxEdaP747qrPSWUQzQjd8xUk9er32nSnXmTs4rnykr589d
# nwN+bid7I61iKWavkugszr2cf9zNFzxDwgk/dUXHnuTXYH+XxuSqx2n1/M10rCyw
# SMFQTnBWHrU1046+se2svf4M7IV91buFZkQZXZ+T64K6Y57TfGH/yBvZI1h/MKNm
# oTkmXpLDPMs3Mvr1o43c1bCj6SU2VdeB+jCCA8QwggMtoAMCAQICEEe/GZXfjVJG
# Q/fbbUgNMaQwDQYJKoZIhvcNAQEFBQAwgYsxCzAJBgNVBAYTAlpBMRUwEwYDVQQI
# EwxXZXN0ZXJuIENhcGUxFDASBgNVBAcTC0R1cmJhbnZpbGxlMQ8wDQYDVQQKEwZU
# aGF3dGUxHTAbBgNVBAsTFFRoYXd0ZSBDZXJ0aWZpY2F0aW9uMR8wHQYDVQQDExZU
# aGF3dGUgVGltZXN0YW1waW5nIENBMB4XDTAzMTIwNDAwMDAwMFoXDTEzMTIwMzIz
# NTk1OVowUzELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMSsw
# KQYDVQQDEyJWZXJpU2lnbiBUaW1lIFN0YW1waW5nIFNlcnZpY2VzIENBMIIBIjAN
# BgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqcqypMzNIK8KfYmsh3XwtE7x38EP
# v2dhvaNkHNq7+cozq4QwiVh+jNtr3TaeD7/R7Hjyd6Z+bzy/k68Numj0bJTKvVIt
# q0g99bbVXV8bAp/6L2sepPejmqYayALhf0xS4w5g7EAcfrkN3j/HtN+HvV96ajEu
# A5mBE6hHIM4xcw1XLc14NDOVEpkSud5oL6rm48KKjCrDiyGHZr2DWFdvdb88qiaH
# XcoQFTyfhOpUwQpuxP7FSt25BxGXInzbPifRHnjsnzHJ8eYiGdvEs0dDmhpfoB6Q
# 5F717nzxfatiAY/1TQve0CJWqJXNroh2ru66DfPkTdmg+2igrhQ7s4fBuwIDAQAB
# o4HbMIHYMDQGCCsGAQUFBwEBBCgwJjAkBggrBgEFBQcwAYYYaHR0cDovL29jc3Au
# dmVyaXNpZ24uY29tMBIGA1UdEwEB/wQIMAYBAf8CAQAwQQYDVR0fBDowODA2oDSg
# MoYwaHR0cDovL2NybC52ZXJpc2lnbi5jb20vVGhhd3RlVGltZXN0YW1waW5nQ0Eu
# Y3JsMBMGA1UdJQQMMAoGCCsGAQUFBwMIMA4GA1UdDwEB/wQEAwIBBjAkBgNVHREE
# HTAbpBkwFzEVMBMGA1UEAxMMVFNBMjA0OC0xLTUzMA0GCSqGSIb3DQEBBQUAA4GB
# AEpr+epYwkQcMYl5mSuWv4KsAdYcTM2wilhu3wgpo17IypMT5wRSDe9HJy8AOLDk
# yZNOmtQiYhX3PzchT3AxgPGLOIez6OiXAP7PVZZOJNKpJ056rrdhQfMqzufJ2V7d
# uyuFPrWdtdnhV/++tMV+9c8MnvCX/ivTO1IbGzgn9z9KMIIFcTCCBFmgAwIBAgIQ
# XM5xW+LS1ji4A9NViFFAMDANBgkqhkiG9w0BAQUFADCBtDELMAkGA1UEBhMCVVMx
# FzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQLExZWZXJpU2lnbiBUcnVz
# dCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2UgYXQgaHR0cHM6Ly93d3cu
# dmVyaXNpZ24uY29tL3JwYSAoYykxMDEuMCwGA1UEAxMlVmVyaVNpZ24gQ2xhc3Mg
# MyBDb2RlIFNpZ25pbmcgMjAxMCBDQTAeFw0xMjA2MTUwMDAwMDBaFw0xNDA3MDky
# MzU5NTlaMIG0MQswCQYDVQQGEwJVUzEWMBQGA1UECBMNTWFzc2FjaHVzZXR0czEP
# MA0GA1UEBxMGQm9zdG9uMR0wGwYDVQQKFBRQcm94eSBOZXR3b3JrcywgSW5jLjE+
# MDwGA1UECxM1RGlnaXRhbCBJRCBDbGFzcyAzIC0gTWljcm9zb2Z0IFNvZnR3YXJl
# IFZhbGlkYXRpb24gdjIxHTAbBgNVBAMUFFByb3h5IE5ldHdvcmtzLCBJbmMuMIIB
# IjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuORukVR3ArkRbmIr7uMEWljY
# GxNuA2MUK0RKXLO8sswGaEPlSq2KeysSQZVScPGcJtkNj+lIsZ5ECM+bYdAJ4Svv
# BTEqt0HKHsovnv7UKFUCoDOHvVZThWA7+58iFrbMMa/QrPWaqBqYMBGyCtRRZjwf
# pE5kWKe617Kcz0w+myqJv/FmOg7mXe5/j25U21/C48q6uE+CzTvm/fv/DhCOZrMH
# ts641LnzX5I3SNv24pMZ0eUU7hGG9J42u+m3D/yC98DkzWIfYnNCcM2COQCkx2FR
# 6MoB2ny6PN+YpdgF2nD71t2LuJMDxVF6PGbE9b+aNMfraRq1rwPfT8BzPwmavQID
# AQABo4IBezCCAXcwCQYDVR0TBAIwADAOBgNVHQ8BAf8EBAMCB4AwQAYDVR0fBDkw
# NzA1oDOgMYYvaHR0cDovL2NzYzMtMjAxMC1jcmwudmVyaXNpZ24uY29tL0NTQzMt
# MjAxMC5jcmwwRAYDVR0gBD0wOzA5BgtghkgBhvhFAQcXAzAqMCgGCCsGAQUFBwIB
# FhxodHRwczovL3d3dy52ZXJpc2lnbi5jb20vcnBhMBMGA1UdJQQMMAoGCCsGAQUF
# BwMDMHEGCCsGAQUFBwEBBGUwYzAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AudmVy
# aXNpZ24uY29tMDsGCCsGAQUFBzAChi9odHRwOi8vY3NjMy0yMDEwLWFpYS52ZXJp
# c2lnbi5jb20vQ1NDMy0yMDEwLmNlcjAfBgNVHSMEGDAWgBTPmanqeyb0S8mOj9fw
# BSbv49KnnTARBglghkgBhvhCAQEEBAMCBBAwFgYKKwYBBAGCNwIBGwQIMAYBAQAB
# Af8wDQYJKoZIhvcNAQEFBQADggEBABDAtzEM2dWEt6wcvi3fSe9Y+hwIS0Oi6Rmf
# QkWMWwHKXvZCOOzuq2i2ywCXnyPz+Fb7waMen0GK2DkfNOwjbjO3yKfDpzv/MHTY
# 1pQjbyf2ySqrRJZ1iqaTDdTe/dhz2PEnp3wIMCM3wX5OCfHEKDUx4BYcLwxaEMAY
# V0j/wJ/vIBdpbDG3GfBUpeRavYjYAEIau7HCMN7lKvWODP09JaePLwfqNzDKB+GY
# cjiEI0gZMY2U4gJ5VygYHGRQslgZ+gVqGg9A6wqWSjqLXBy8C5CRNQmds+e6081Y
# b3WvPbwtI1lGTNmJDCTkJuXDk2S5LDkOEg4DpilD1nN7MiqzRf0wggYKMIIE8qAD
# AgECAhBSAOWqJVb8GobtlsnUSzPHMA0GCSqGSIb3DQEBBQUAMIHKMQswCQYDVQQG
# EwJVUzEXMBUGA1UEChMOVmVyaVNpZ24sIEluYy4xHzAdBgNVBAsTFlZlcmlTaWdu
# IFRydXN0IE5ldHdvcmsxOjA4BgNVBAsTMShjKSAyMDA2IFZlcmlTaWduLCBJbmMu
# IC0gRm9yIGF1dGhvcml6ZWQgdXNlIG9ubHkxRTBDBgNVBAMTPFZlcmlTaWduIENs
# YXNzIDMgUHVibGljIFByaW1hcnkgQ2VydGlmaWNhdGlvbiBBdXRob3JpdHkgLSBH
# NTAeFw0xMDAyMDgwMDAwMDBaFw0yMDAyMDcyMzU5NTlaMIG0MQswCQYDVQQGEwJV
# UzEXMBUGA1UEChMOVmVyaVNpZ24sIEluYy4xHzAdBgNVBAsTFlZlcmlTaWduIFRy
# dXN0IE5ldHdvcmsxOzA5BgNVBAsTMlRlcm1zIG9mIHVzZSBhdCBodHRwczovL3d3
# dy52ZXJpc2lnbi5jb20vcnBhIChjKTEwMS4wLAYDVQQDEyVWZXJpU2lnbiBDbGFz
# cyAzIENvZGUgU2lnbmluZyAyMDEwIENBMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A
# MIIBCgKCAQEA9SNLXqXXirsy6dRX9+/kxyZ+rRmY/qidfZT2NmsQ13WBMH8EaH/L
# K3UezR0IjN9plKc3o5x7gOCZ4e43TV/OOxTuhtTQ9Sc1vCULOKeMY50Xowilq7D7
# zWpigkzVIdob2fHjhDuKKk+FW5ABT8mndhB/JwN8vq5+fcHd+QW8G0icaefApDw8
# QQA+35blxeSUcdZVAccAJkpAPLWhJqkMp22AjpAle8+/PxzrL5b65Yd3xrVWsno7
# VDBTG99iNP8e0fRakyiF5UwXTn5b/aSTmX/fze+kde/vFfZH5/gZctguNBqmtKdM
# fr27Tww9V/Ew1qY2jtaAdtcZLqXNfjQtiQIDAQABo4IB/jCCAfowEgYDVR0TAQH/
# BAgwBgEB/wIBADBwBgNVHSAEaTBnMGUGC2CGSAGG+EUBBxcDMFYwKAYIKwYBBQUH
# AgEWHGh0dHBzOi8vd3d3LnZlcmlzaWduLmNvbS9jcHMwKgYIKwYBBQUHAgIwHhoc
# aHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYTAOBgNVHQ8BAf8EBAMCAQYwbQYI
# KwYBBQUHAQwEYTBfoV2gWzBZMFcwVRYJaW1hZ2UvZ2lmMCEwHzAHBgUrDgMCGgQU
# j+XTGoasjY5rw8+AatRIGCx7GS4wJRYjaHR0cDovL2xvZ28udmVyaXNpZ24uY29t
# L3ZzbG9nby5naWYwNAYDVR0fBC0wKzApoCegJYYjaHR0cDovL2NybC52ZXJpc2ln
# bi5jb20vcGNhMy1nNS5jcmwwNAYIKwYBBQUHAQEEKDAmMCQGCCsGAQUFBzABhhho
# dHRwOi8vb2NzcC52ZXJpc2lnbi5jb20wHQYDVR0lBBYwFAYIKwYBBQUHAwIGCCsG
# AQUFBwMDMCgGA1UdEQQhMB+kHTAbMRkwFwYDVQQDExBWZXJpU2lnbk1QS0ktMi04
# MB0GA1UdDgQWBBTPmanqeyb0S8mOj9fwBSbv49KnnTAfBgNVHSMEGDAWgBR/02Wn
# wt3su/AwCfNDOfoCrzMxMzANBgkqhkiG9w0BAQUFAAOCAQEAViLmNKTEYctIuQGt
# VqhkD9mMkcS7zAzlrXqgIn/fRzhKLWzRf3EafOxwqbHwT+QPDFP6FV7+dJhJJIWB
# JhyRFEewTGOMu6E01MZF6A2FJnMD0KmMZG3ccZLmRQVgFVlROfxYFGv+1KTteWsI
# DEFy5zciBgm+I+k/RJoe6WGdzLGQXPw90o2sQj1lNtS0PUAoj5sQzyMmzEsgy5Af
# XYxMNMo82OU31m+lIL006ybZrg3nxZr3obQhkTNvhuhYuyV8dA5Y/nUbYz/OMXyb
# jxuWnsVTdoRbnK2R+qztk7pdyCFTwoJTY68SDVCHERs9VFKWiiycPZIaCJoFLseT
# pUiR0zGCA+4wggPqAgEBMIHJMIG0MQswCQYDVQQGEwJVUzEXMBUGA1UEChMOVmVy
# aVNpZ24sIEluYy4xHzAdBgNVBAsTFlZlcmlTaWduIFRydXN0IE5ldHdvcmsxOzA5
# BgNVBAsTMlRlcm1zIG9mIHVzZSBhdCBodHRwczovL3d3dy52ZXJpc2lnbi5jb20v
# cnBhIChjKTEwMS4wLAYDVQQDEyVWZXJpU2lnbiBDbGFzcyAzIENvZGUgU2lnbmlu
# ZyAyMDEwIENBAhBcznFb4tLWOLgD01WIUUAwMAkGBSsOAwIaBQCgeDAYBgorBgEE
# AYI3AgEMMQowCKACgAChAoAAMBkGCSqGSIb3DQEJAzEMBgorBgEEAYI3AgEEMBwG
# CisGAQQBgjcCAQsxDjAMBgorBgEEAYI3AgEVMCMGCSqGSIb3DQEJBDEWBBTjMU8+
# PtSbq4kdPuRel8k6Af9nDzANBgkqhkiG9w0BAQEFAASCAQCdskLJV31mmcayyDI2
# 8MyjZEh3hUFURQ0FJ9QMvlDRKU9Vw5lnnK4hP4PjqbGp844UVKYqJuHAQsCwV+cM
# obSW/nyoYSGmbch2UGb7dXrkFxyUV3cQsFf+MN07Dt+AjC/dPe0UE9M1OTn2BCH0
# mKOR7q6geFH5xsfmBafM3N/pHPd13x2XYt6BTodU9hiD9DhaFiGCfmk/g4Q1jGbA
# L8VgRbydeeZ6h7E466861jC53LWYM2VDlJIgP3ihwrr2SKEXPrDOgl89rleB9BW8
# j2NenEKNg3gSg9hHKxWRzgx8A3nHxr+yfPxDQctYzQinDYBOWybRxgRO6XI7mTMy
# +aKIoYIBfzCCAXsGCSqGSIb3DQEJBjGCAWwwggFoAgEBMGcwUzELMAkGA1UEBhMC
# VVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMSswKQYDVQQDEyJWZXJpU2lnbiBU
# aW1lIFN0YW1waW5nIFNlcnZpY2VzIENBAhB5oqWF+dEVQhPZuD72to3tMAkGBSsO
# AwIaBQCgXTAYBgkqhkiG9w0BCQMxCwYJKoZIhvcNAQcBMBwGCSqGSIb3DQEJBTEP
# Fw0xMjA4MDgyMjU1NTNaMCMGCSqGSIb3DQEJBDEWBBQBShYnpDrtFvQmlyyrt1Hf
# vCVaYTANBgkqhkiG9w0BAQEFAASBgCrYnEMa0BoK+mTcD0ED8VTQakrBLdfl1DFW
# 2R18AADa8mPwnL+h0Pdkt2KouBa+npAp1gRsuBoTlx2DSdm1W0gjNXdKjAT+Bzd4
# Mu5hJK0DINgaJOufvwe0FTF/vDpYyjGE35elgVDCnDS6tzkvkGQvVdmy8lCv3aO7
# mG7qQRy6
# SIG # End signature block
