##############################################################################
##
## Power Shell Script for Adding a Gateway configuartion to Host Settings
## Script assumes the target Host is already connected-to
##
## Examples:
## 
## PS> .\AddGatewayToHost.ps1 -gwid 'w={guid}' -gateway 'localhost' -protocol 'tcp'
## 
## PS> Set-ExecutionPolicy -Scope Process -executionPolicy RemoteSigned -Force
## PS> Import-Module Proxy-Gateway
## PS> $hh = Connect-Host -gateway 'specifier' -hostkey 'w={guid}'
## PS> .\AddGatewayToHost.ps1 -gwid 'w={gatewayID} -gateway 'specifier' -protocol 'tcp'
## 
##############################################################################

param(
	[string]$gwid = $(throw "Please provide the WorkstationID of the Gateway Server in 'w={guid}' format")
	, [string]$gateway = $(throw "Please provide Gateway station specifier")
    , [string]$protocol ='TCP')

# Imports
if (-not (Get-Module Proxy-Utils))
{
    Import-Module Proxy-Utils
}
if (-not (Get-Module Proxy-HostAdmin))
{
    Import-Module Proxy-HostAdmin
}
if (-not (Get-Module Proxy-Constants))
{
    Import-Module Proxy-Constants
}

# Add the specified Gateway to the Host Gateway configuration list, if it's not already there

$found = 0
$hh = Get-HostConnection
if (-not $hh)
{
    Write-Error -message "Must have already connected Host for administration via Connect-Host"
    return
}

$msg = "Adding Gateway Config ($gateway  via $protocol) with ID=$gwid to Host " + $hh.settings.stationName + " (if not already there)"
Write-Verbose $msg

foreach ($gconfig in $hh.settings.getGatewayConfigs())
{
    if ($gconfig.gatewayGUID -eq $gwid)
    {
        $found = 1
        $msg = "Gateway not added: found matching key=" + $gconfig.gatewayKey + " (" + $gconfig.gatewayStationSpecifier + " via " + $gconfig.gatewayProtocol + ")"
    	Write-Verbose $msg
    	continue
    }
}

if ($found -eq 0)
{
	$gconfigKey = $hh.settings.addGatewayConfig($protocol, $gateway, -1, 0, 0)
  	$msg = "ACTION: Added Gateway Config key=" + $gconfigKey + " (" + $gateway + " via " + $protocol + ")"
  	Write-Output $msg
}
