﻿##############################################################################
##
## Power Shell Script to delete Gateway Groups that match a pattern
##
## Examples:
## 
## PS> .\Delete-MatchingGatewayGroups.ps1 -gateway 'localhost'
## 
##############################################################################

param(
	[string]$gateway = $(throw "Please provide Gateway Identifier")
    , [string]$protocol ='TCP'
    , [string]$credentials = '')

# Imports
if (-not (Get-Module Proxy-Gateway))
{
    Import-Module Proxy-Gateway
}

# Make sure there are no current connections

disconnect-gateway

# Connect to Gateway

$result = Connect-Gateway -station $gateway -protocol $protocol -credentials $credentials
$gw = Get-GatewayObject
if (-not $gw)
{
    Write-Error -message "Failed to connect to Gateway Server - exiting"
    return
}

# Get all of the Gateway Groups, find the subset that match the pattern,
# then walk that list and delete each group.

$gws = Get-GatewayObject
$groups = $gw.getGroups()
$badgroups = $groups | ? {$_.groupname -match "^OU="}
foreach ($badgroup in $badgroups)
{
		$n = $badgroup.groupname
		Write-Output "Deleting group: $n"
    $badgroup.deletegroup()
} 

disconnect-gateway
