##############################################################################
##
## Power Shell Script for retrieving Host Settings as XML.
##
## Examples:
## 
## PS> .\Get-HostSettingsToXML.ps1 -gateway 'localhost' -hostkey '07C9B233-1BA8-4A48-81C8-2454E537C479' # Using logged-in user's credentials
## PS> .\Get-HostSettingsToXML.ps1 -gateway 'localhost' -hostkey '07C9B233-1BA8-4A48-81C8-2454E537C479' -credentials "domain\name|password"
## 
## PS> Set-ExecutionPolicy -Scope Process -executionPolicy RemoteSigned -Force
## PS> Import-Module Proxy-Gateway
## PS> Connect-Gateway 'localhost'
## PS> $gws.getHosts() | where { $_.machine -ne 'virtual' } | % { .\Get-HostSettingsToXML.ps1 'localhost' $_.workstationKey }
## PS> Disconnect-Gateway
## 
##############################################################################

param(
	[string]$gateway = $(throw "Please provide Gateway Identifier")
	, [string]$hostkey = $(throw "Please provide Host Key")
    , [string]$protocol ='TCP'
    , [string]$credentials = '')

# Imports
if (-not (Get-Module Proxy-Utils))
{
    Import-Module Proxy-Utils
}
if (-not (Get-Module Proxy-HostAdmin))
{
    Import-Module Proxy-HostAdmin
}
if (-not (Get-Module Proxy-Constants))
{
    Import-Module Proxy-Constants
}

# Connect Host Administration object
$hostHA = Connect-Host -gateway $gateway -hostkey $hostkey -protocol $protocol -credentials $credentials
if(-not $hostHA)
{
	Write-Error -message "Can't connect to Host." 
    return $false
}

$results = @($hostha.settings, @($hostha.settings.getGatewayConfigs())) | ConvertTo-Xml -As string -Depth 2

# Disconnect Host Administration object
Disconnect-Host

return $results