##############################################################################
##
## Power Shell Script for Removing a Gateway configuartion from Host Settings
## Script assumes the target Host is already connected-to
##
##
## Examples:
## 
## PS> .\RemoveGatewayFromHost.ps1 -gwid 'w={guid}' -gatewayList @( 'specifier1', 'specifier2' )
## 
## PS> Set-ExecutionPolicy -Scope Process -executionPolicy RemoteSigned -Force
## PS> Import-Module Proxy-HostAdmin
## PS> $hh = Connect-Host -gateway 'specifier' -hostkey 'w={guid}'
## PS> .\RemoveGatewayFromHost.ps1 -gwid 'w={gatewayID} -gateway 'specifier'
## 
##############################################################################

param(
	[string]$gwid = $(throw "Please provide the WorkstationID of the Gateway Server in 'w={guid}' format")
	, $gatewayList = '')

# Imports
if (-not (Get-Module Proxy-Utils))
{
    Import-Module Proxy-Utils
}
if (-not (Get-Module Proxy-HostAdmin))
{
    Import-Module Proxy-HostAdmin
}
if (-not (Get-Module Proxy-Constants))
{
    Import-Module Proxy-Constants
}

# Remove the specified Gateway to the Host Gateway configuration list, if it's there
# Note well that the BEST MATCH is via WorkstationID, but that presumes that the Host was
# able to contact the Gateway.  We also match any of the list of station specifiers

$hh = Get-HostConnection
if (-not $hh)
{
    Write-Error -message "Must have already connected Host for administration via Connect-Host"
    return
}

$msg = "Removing Gateway Configs with ID=$gwid or StationSpecifiers=($gatewayList) from Host " + $hh.settings.stationName
Write-Verbose $msg

foreach ($gconfig in $hh.settings.getGatewayConfigs())
{
    if ($gconfig.gatewayGUID -eq $gwid)
    {
        $msg = "ACTION: removing Gateway Config key=" + $gconfig.gatewayKey + " (" + $gconfig.gatewayStationSpecifier + " via " + $gconfig.gatewayProtocol + ")"
    	Write-Output $msg
    	$gconfig.deleteGatewayConfig()
    	continue
    }
    foreach ($ss in $gatewayList)
    {
	    if ($gconfig.gatewayStationSpecifier -eq $ss)
	    {
	        $msg = "ACTION: removing Gateway Config key=" + $gconfig.gatewayKey + " (" + $gconfig.gatewayStationSpecifier + " via " + $gconfig.gatewayProtocol + ")"
	    	Write-Output $msg
	    	$gconfig.deleteGatewayConfig()
	    	continue
	    }
    }
}
