##############################################################################
##
## Power Shell Script for reporting on existing Gateway Configurations for Hosts
##
## Examples:
## 
## PS> .\ReportAllHostsOnGateway.ps1 -gateway 'localhost'
## 
##############################################################################

param(
	[string]$gateway = $(throw "Please provide Gateway Identifier")
    , [string]$protocol ='TCP'
    , [string]$credentials = '')

# Imports
if (-not (Get-Module Proxy-Utils))
{
    Import-Module Proxy-Utils
}
if (-not (Get-Module Proxy-HostAdmin))
{
    Import-Module Proxy-HostAdmin
}
if (-not (Get-Module Proxy-Constants))
{
    Import-Module Proxy-Constants
}
if (-not (Get-Module Proxy-Gateway))
{
    Import-Module Proxy-Gateway
}

# Make sure there are no current connections

disconnect-host
disconnect-gateway

# Connect to Gateway and get list of All Hosts

$result = Connect-Gateway -station $gateway -protocol $protocol -credentials $credentials
$gw = Get-GatewayObject
if (-not $gw)
{
    Write-Error -message "Failed to connect to Gateway Server - exiting"
    return
}

# For each host in the "All Hosts" group, connect Host Administration object & process it

foreach ($hh in $gw.getWorkstations())
{
	if (($hh.isManaged -eq 0) -or ($hh.protocol -eq 'internal') -or ($hh.address -eq ''))
	{
		continue
	}
	if ($hh.machine -eq "")
	{
		$msg = "Processing Host on station=" + $hh.name + " (HostID=" + $hh.key + ")"
	}
	else
	{
		$msg = "Processing Host on " + $hh.machine + " (HostID=" + $hh.key + ")"
	}
	Write-Output $msg
	$hostHA = Connect-Host -gateway $gateway -hostkey $hh.key -protocol $protocol -credentials $credentials
	if(-not $hostHA)
	{
		# Note: error reported by Connect-Host cmdlet
		# $msg = "Cannot connect to Host with key = " + $hh.key
		# Write-Error -message $msg
		continue
	}

### Report on Gateway Configs for that Host

	if ($hostHA.settings.useWindowsSecurity -eq 0)
	{
		$msg = "     WARNING: Host " + $hh.machine + " (HostID=" + $hh.key + ") is configured for SIMPLE PASSWORD"
		Write-Output $msg
		if ($hostHA.settings.isPasswordSet -eq 0)
		{
			$msg = "     WARNING: Host " + $hh.machine + " (HostID=" + $hh.key + ") is configured with a BLANK PASSWORD"
			Write-Output $msg
		}
	}
	foreach ($gconfig in $hostHA.settings.getGatewayConfigs())
	{
		$msg = "     " + $gconfig.gatewayStationSpecifier + " via " + $gconfig.gatewayProtocol
		Write-Output $msg
	}

	# Disconnect Host Administration object
	Disconnect-Host
}

