##############################################################################
##
## Power Shell Script for invoking Copy-HostToGroupsByPolicy helper to
## organize managed Hosts in Gateway Server by Active Directory structure
##
##############################################################################

# Imports
if (-not (Get-Module Proxy-Utils))
{
    Import-Module Proxy-Utils
}
if (-not (Get-Module Proxy-Gateway))
{
    Import-Module Proxy-Gateway
}
if (-not (Get-Module Proxy-Gateway-Utils))
{
    Import-Module Proxy-Gateway-Utils
}

# Policy to Copy Host to Groups with the same names as Organizational Units to wich Host belongs according to default AD
$organizational_policy = {
    param($host_object)

	# Import Proxy common PS utilities
	Import-Module Proxy-Utils
    # Import WMI helpers for AD 
    Import-Module Proxy-Gateway-ADs

    # Get Host's OUs
    $adObj = Get-ComputerInDefaultAD $host_object.machine
    if(-not $adObj)
    {
        Write-Warning -Message "Host machine: $host_object.machine, wasn't found in default AD."
        return
    }

    # Returns the list of Organizational Units names for the given Host
    return ([adsi]($adObj.GetDirectoryEntry().parent)).ou
}

# Connect to Proxy Gateway
Connect-Gateway 'localhost'
if(Test-Connection)
{
    $gws = Get-GatewayObject

    # Execute the policy
    Copy-HostToGroupsByPolicy -prxGWS $gws -policy $organizational_policy -forceGroupCreation $true
    
    Disconnect-Gateway
}
