##############################################################################
##
## Power Shell Script demonstrates how to monitor for Gateway notifications
##
##############################################################################

# Imports
if (-not (Get-Module Proxy-Utils))
{
    Import-Module Proxy-Utils
}
if (-not (Get-Module Proxy-Gateway))
{
    Import-Module Proxy-Gateway
}
if (-not (Get-Module Proxy-Gateway-Utils))
{
    Import-Module Proxy-Gateway-Utils
}
if (-not (Get-Module PSLog))
{
    Import-Module PSLog
}

#
# Start the logging with PSLog(http://gallery.technet.microsoft.com/scriptcenter/PSLog-Send-messages-to-a-db389927).
# It will redirect all Write-* to the log file once started. Put log files in the same root directory where 
# PowerShell persists results from the Scheduled Jobs.
#
$logdir = $home + "\AppData\Local\Microsoft\Windows\PowerShell\ScheduledJobs"

# If there was parameter passed into the script, - use it as a log file name.
if($args) {
    $logname = $args[0]
}
else {
    $logname = [System.Guid]::NewGuid().Guid
}

Start-Log -LogPath $logdir -LogName $logname -Level Information

#
# Register PowerShell engine event "exit" to run Disconnect-Gateway
#
function global:onExit {
    Write-Host "Exiting."
    Disconnect-Gateway
}

$null = Register-EngineEvent -SourceIdentifier `
     ([System.Management.Automation.PsEngineEvent]::Exiting) -Action {onExit}

#
# Main loop: Connect to Proxy Gateway and wait for the events. Reconnect if connection 
# failed after some delay.
#
do {
    do {
        # Try to connect to Gateway
        Connect-Gateway 'localhost'

        if(Test-Connection) {
            # We have connection, go to waiting for events
            Write-Host "Connected to the Gateway."
            break;
        }
        else {
            # If connection is failed - wait for 10sec before trying again
            sleep 10
        }
    }
    while($true)

    # Register an example event action from Proxy-Gateway module for Group Membership Change 
    # event. It will print properties of Group Membership Change event when it happens.
    Register-GroupMembershipChange $template_event_group_membership_action

    Write-Host "Waiting for Group Membership Change events."

    do {
        # Wait for any event, periodically checking if we still have Gateway connection.
        # When event happens it will trigger the registered action. 
        # Here we can just use `sleep 5` but than it will wait for 5 sec to notify about event.
        $null = Wait-Event -Timeout 5
    } while ((Test-Connection))

    # We lost the connection. Going to the beginning of the loop to reconnect.
    Write-Host "Connection to the Gateway is lost. Trying to reconnect."        
}
while($true)

